# -*- coding: utf-8 -*-

from .setuptools_wrap import setup  # noqa: F401

__author__ = 'The scikit-build team'
__email__ = 'scikit-build@googlegroups.com'
__version__ = '0.2.0'

__all__ = ["setup"]
